//-----------------------------------------------------------------------------
// Title         : HT Top Control
// Project       : HT Testbench
//-----------------------------------------------------------------------------
// File          : csco_ht_top_control.e
// Author        : Brian Van Essen  <vanessen@cisco.com>
// Created       : 25.01.2001
// Last modified : 02.05.2001
//-----------------------------------------------------------------------------
// Description :
// A top level file that imports all of the necessary files for the HT testbench.
// In order to incorportate the HT model into an environemnt this is the only
// file that needs to be included, and it will bring together the rest of the model.
//------------------------------------------------------------------------------
// Modification history :
// 25.01.2001 : created
// 26/11/2002 : Added QED coverage file and other compat enhancements for
//              Specman 4.1
//
//-----------------------------------------------------------------------------

// ***** BEGIN LICENSE BLOCK *****
// Version: MPL 1.1
// The contents of this file are subject to the Mozilla Public License Version
// 1.1 (the "License"); you may not use this file except in compliance with
// the License. You may obtain a copy of the License at
// http:                                                   // www.mozilla.org/MPL/ or ./mpl_1_1.txt
// Software distributed under the License is distributed on an "AS IS" basis,
// WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
// for the specific language governing rights and limitations under the License.
// The Original Code is Cisco Hypertransport eVC.
// The Initial Developer of the Original Code is
// Brian Van Essen, Lisa Huang, and Sean Smith.
// Portions created by the Initial Developer are Copyright (C) 2002
// the Initial Developer. All Rights Reserved.
// Contributor(s): Brian Van Essen, Lisa Huang, and Sean Smith
// ***** END LICENSE BLOCK *****


// csco_ht_device                   csco_ht_device                   csco_ht_device
// -------------- csco_ht_link_pair -------------- csco_ht_link_pair --------------
// | Host       |                   | Tunnel I/O |                   | EOC I/O    |
// | Bridge     |  downstream       | Device     |  downstream       | Device     |
// |            |------------------>|            |------------------>|            |
// |       EOC  |                   | HOC   EOC  |                   | HOC        |
// |       Pair |<------------------| Pair  Pair |<------------------| Pair       |
// |            |   upstream        |            |   upstream        |            |
// --------------                   --------------                   --------------
//
// Bus/Link identification:
// A single HT daisy chain, from host bridge to the end of chain device, is refered to as a single bus.
// Each link pair within a bus are refered to by a specific link id, 0 is the link connecting the host bridge
// to the first IO device, and so on down to the last device on the chain.
//
// hoc -> head of chain
// eoc -> end of chain
// upstream -> traffic traveling towards the host bridge.
// downstream -> traffic travelling towards the end of chain.
// upstream_interface -> the interface closest to the Host Bridge (i.e. the link with a tx upstream path).
// downstream_interface -> the inteface pointing away from the Host Bridge. (i.e. the link with a tx downstream path).
//
// The HT model is divided into several logical parts:
//
// The link interface is the lowest level of the HT model and is the part that actually interacts with the
// bus at a wire level.  It is the single point of contact for the model to interact with the DUT and is
// responsible for framing a HT packet into the appropriate number of bit times and generating/checking
// the CRC for each bit lane.
//
// The Channel is the logical interface to the HT link.  It handles all HT traffic at the packet level
// an manages the inbound and outbound packet ordering.  It takes the HT packets and helps to
// assemble/disassemble the packet for interaction with the link interface.  The channel
// allows the device to present packets to be transmitted and with handle the scheduling.
// Additionally the channel will present received packets to the device.
//
// The Device is the brains of a node sitting on the HT chain.  It is responsible for generating
// and managing traffic at a high level.  It will then pass the desired traffic to the HT Channel
// for interaction with the actual HT protocol/bus.
//
// NOTES: During simulation there are three types of errors that can occur.
// csco_ht_protocol_errors: These indicate that something in the HT protocol was violated. (e.g. CRC)
// csco_ht_transaction_errors: These indicate that an HT transaction failed in some way. (e.g. Read or Write Error)
// dut_errors: These should only occur if the testbench some how performs an illegal action, and indicate
//             that the testbench is misbehaving.  In the case of a dut_error, please contact Brian Van Essen
//             (vanessen@cisco.com) for further assistance, or go debug the testbench.
//

<'

// Import Core Features (This seperation of core verses features
// allows for the core to be compiled and accelerated.)
import csco_ht_core;

// Import Enhancments

import (csco_ht_io_device, csco_ht_host_bridge, csco_ht_scenario_definitions);
import csco_ht_coverage.e;
import csco_ht_qed_coverage.e;

'>
